@@ -1,9 +1,9 @@
 import numpy as np
 
+from worker.data.api import API
+
 
 def gather_wits_for_period(asset_id, start, end, limit=1800):
-    from worker.data.api import API
-
     query = '{timestamp#gte#%s}AND{timestamp#lte#%s}' % (start, end)
     worker = API()
     wits_dataset = worker.get(
@@ -17,13 +17,26 @@ def gather_wits_for_period(asset_id, start, end, limit=1800):
 
 
 def get_config_by_id(config_collection, _id):
-    from worker.data.api import API
-
     worker = API()
     config = worker.get(path="/v1/data/corva/%s/%s" % (config_collection, _id)).data
     return config
 
 
+def delete_collection_data_of_asset_id(asset_id, collection):
+    """
+    Delete all the data of a collection for an asset id.
+    :param asset_id:
+    :param collection:
+    :return:
+    """
+    worker = API()
+
+    path = "/v1/data/corva/%s" % collection
+    query = "{asset_id#eq#%s}" % asset_id
+    worker.delete(path=path, query=query)
+    print(f"Deleted {collection} for asset_id {asset_id}.")
+
+
 def is_number(data):
     """
     Check and return True if data is a number, else return False
