@@ -1,7 +1,7 @@
 import unittest
 import numpy as np
 from worker.data import math
-from worker.data.operations import is_number, to_number, none_to_nan, is_finite
+from worker.data.operations import is_number, to_number, none_to_nan, is_finite, get_value_from_dict, get_dict_data_by_path
 
 
 class TestGeneral(unittest.TestCase):
@@ -33,6 +33,12 @@ class TestGeneral(unittest.TestCase):
         np.testing.assert_equal(none_to_nan([1, 2, None]), [1, 2, np.nan])
         np.testing.assert_equal(none_to_nan([1, 2, 3, np.nan, None]), [1, 2, 3, np.nan, np.nan])
 
+        self.assertTrue(get_value_from_dict(dict(name="X", value=2.3), 'value', float), 2.3)
+        self.assertTrue(get_value_from_dict(dict(name="X", value=2.3), 'property', float, 1.0), 1.0)
+
+        self.assertTrue(get_dict_data_by_path(dict(name={'first_name': 'foo', 'last_name': 'bar'}, value=2.3), 'name.first_name'), 'foo')
+        self.assertTrue(get_dict_data_by_path(dict(p1={'p2': 1.2}), 'p1.p2'), 1.2)
+
     def test_math_utils(self):
         self.assertEqual(math.percentile([1, 2, None, np.nan], 50), 1.5)
         self.assertEqual(math.percentile([None, 1, np.nan], 50), 1.0)
